x2 + y2 = 4

Textsuperscript

Text^superscript failed^

Textsuperscript success

Test: ^^ Won't insert ^^

Test: Will insert

Test: ^^Escaped^^

Test: This will all be inserted ^^because of the placement of the center carets.

Test: This will all be inserted ^^ because of the placement of the center carets.

Test: This will NOT all be inserted because of the placement of the center caret.^^

Test: This will all be inserted^ because of the token is less than that of the caret.